@@ -26,9 +26,9 @@ osmo-build-dep.sh libasn1c
 # the asn1c binary is used by the 'regen' target below
 osmo-build-dep.sh asn1c aper-prefix
 
-CONFIG=""
+CONFIG="--enable-werror"
 if [ "$WITH_MANUALS" = "1" ]; then
-	CONFIG="--enable-manuals"
+	CONFIG="$CONFIG --enable-manuals"
 fi
 
 set +x
@@ -62,9 +62,5 @@ $MAKE check \
 $MAKE $PARALLEL_MAKE distcheck \
   || cat-testlogs.sh
 
-if [ "$WITH_MANUALS" = "1" ] && [ "$PUBLISH" = "1" ]; then
-	make -C "$base/doc/manuals" publish
-fi
-
 $MAKE $PARALLEL_MAKE maintainer-clean
 osmo-clean-workspace.sh
